<template>
    <div class="system-menu-dialog-container">
        <el-dialog :title="roomDialogState.title" v-model="roomDialogState.roomDialogVisible" width="600px">
            <el-form ref="roomFormRef" :rules="roomDialogState.roomFormRules" :model="roomDialogState.roomForm" size="default" label-width="120px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="场所名称" prop="siteName">
                            <el-input v-model="roomDialogState.roomForm.siteName" placeholder="场所名称" clearable class="input-length"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="实验室所在楼" prop="floor">
                            <el-input v-model="roomDialogState.roomForm.floor" placeholder="实验室所在楼" clearable class="input-length"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="实验室所在房间" prop="room">
                            <el-input v-model="roomDialogState.roomForm.room" placeholder="实验室所在房间" clearable class="input-length"></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
				<span class="dialog-footer">
					<el-button @click="roomDialogState.roomDialogVisible = !roomDialogState.roomDialogVisible" size="default">取 消</el-button>
					<el-button type="primary" @click="onSubmitRoom" size="default">确定</el-button>
				</span>
            </template>
        </el-dialog>
    </div>
</template>

<script setup lang="ts">
import { reactive, ref } from "vue";
import {ElMessage} from "element-plus";
import {roomApi} from "/@/api/basic/room";

const roomFormRef = ref()

const roomDialogState = reactive<RoomDialogType>({
    title: '',
    roomDialogVisible: false,
    roomForm: {
        siteName: '',
        floor: '',
        room: '',
    },
    roomFormRules: {
        deviceCode: [{ required: true, message: '请填写设备编号', trigger: 'blur' }],
        deviceName: [{ required: true, message: '请填写设备名称', trigger: 'blur' }],
        devicePower: [{ required: true, message: '请填写设备功率', trigger: 'blur' }],
        deviceUnit: [{ required: true, message: '请选择计量单位', trigger: 'change' }]
    },
    specialDeviceList: [],
    deviceUnitList: [
        {id:1, name: '台'},
        {id:2, name: '个'},
        {id:3, name: '件'}
    ]
})

const showroomDialog = (title: string, value: RoomType, specialDeviceList: Type []) => {

    roomDialogState.roomDialogVisible = true;
    roomDialogState.specialDeviceList = specialDeviceList;
    setTimeout(() => {
        roomFormRef.value.clearValidate();
    });
    if(title === '新增'){
        roomDialogState.title = '新增';
        roomDialogState.roomForm = {
            siteName: '',
            floor: '',
            room: '',
        };
    }else{
        roomDialogState.title = '编辑'
        roomDialogState.roomForm = {
            id: value.id,
            siteName: value.siteName,
            floor: value.floor,
            room: value.room,
        };
    }
};

const onSubmitRoom = () => {
    roomFormRef.value.validate(async(valid: boolean) => {
        if(valid){
            if(roomDialogState.title === '新增'){
                let res = await roomApi().addRoom(roomDialogState.roomForm);
                if(res.data.code === 100){
                    emit('refresh')
                    roomDialogState.roomDialogVisible = false;
                    ElMessage({
                        type: 'success',
                        message: '新增成功'
                    })
                }else{
                    ElMessage({
                        type: 'warning',
                        message: res.data.msg,
                    });
                }
            }else{
                let res = await roomApi().modRoom(roomDialogState.roomForm)
                if(res.data.code === 100){
                    emit('refresh')
                    roomDialogState.roomDialogVisible = false;
                    ElMessage({
                        type: 'success',
                        message: '编辑成功'
                    })
                }else{
                    ElMessage({
                        type: 'warning',
                        message: res.data.msg,
                    });
                }
            }
        }else{
            ElMessage({
                type: 'warning',
                message: '请完善基本信息',
            });
        }
    })
}

const emit = defineEmits(['refresh'])

defineExpose({
    showroomDialog
})
</script>

<style scoped>

</style>
